# firefox-bookmarks

Manage your Firefox bookmarks with ease

## installation

```shell
pip install firefox-bookmarks
```

## examples

See [the examples directory](https://github.com/BURG3R5/firefox-bookmarks/tree/main/examples)

## license

Copyright (C) 2023 Aditya Rajput & other contributors

This software is licensed under the **Affero GPL v3**. You should have received [a copy](https://github.com/BURG3R5/firefox-bookmarks/blob/main/LICENSE) of the Affero GPL v3 along with this program. If not, you can visit the original [here](https://www.gnu.org/licenses/agpl-3.0.html#license-text).
